#!/bin/sh
set -ev

cd $(realpath $(dirname "${0}"))/install

# Check prerequisites
[ ! -e /run/openrc/started/postgres ] && service postgres start && STOP_POSTGRES=1

# Populate database
export KANBOARD_PWD=$(head -c 18 /dev/urandom | base64)
envsubst <createdb.sql | lxc-attach -u 5432 -g 5432 postgres -- psql
cat /var/lib/lxc/kanboard/kanboard/srv/kanboard/app/Schema/Sql/postgres.sql | lxc-attach -u 5432 -g 5432 postgres -- sh -c "PGPASSWORD=${KANBOARD_PWD} psql kanboard kanboard"

# Configure Kanboard
mkdir -p /srv/kanboard/conf /srv/kanboard/data
chown -R 8009:8009 /srv/kanboard/data
envsubst <srv/kanboard/conf/config.php >/srv/kanboard/conf/config.php
export KANBOARD_ADMIN_USER=admin
export KANBOARD_ADMIN_PWD=$(head -c 12 /dev/urandom | base64)
export KANBOARD_ADMIN_HASH=$(python3 -c "import bcrypt; print(bcrypt.hashpw('${KANBOARD_ADMIN_PWD}'.encode(), bcrypt.gensalt()).decode().replace('2b', '2y'))")
envsubst <adminpwd.sql | lxc-attach -u 5432 -g 5432 postgres -- psql kanboard

# Install cron job
cp etc/periodic/daily/kanboard /etc/periodic/daily/kanboard

# Install service
cp etc/init.d/kanboard /etc/init.d/kanboard
rc-update -u

# Install config update script
cp srv/kanboard/update-conf.sh /srv/kanboard/update-conf.sh

# Stop services required for build
[ ! -z ${STOP_POSTGRES} ] && service postgres stop

# Register application
vmmgr register-app kanboard kb "${KANBOARD_ADMIN_USER}" "${KANBOARD_ADMIN_PWD}"
